@@ -1,10 +1,10 @@
 from .t2t import map_terms
 from .t2t import map_file
-from .t2t import cache_ontology_set
-from .t2t import cache_ontology
-from .t2t import cache_exists
-from .t2t import clear_cache
 from .t2t import map_tagged_terms
+from .t2t import cache_ontology
+from .onto_cache import cache_ontology_set
+from .onto_cache import cache_exists
+from .onto_cache import clear_cache
 from .mapper import Mapper
 from .preprocess import preprocess_file
 from .preprocess import preprocess_terms
