@@ -37,6 +37,8 @@ if __name__ == "__main__":
                         help="Save vis.js graphs representing the neighborhood of each ontology term (default=False)")
     parser.add_argument("-c", "--store_in_cache", required=False, type=str, default="",
                         help="Store the target ontology into local cache under acronym")
+    parser.add_argument("-type", "--term_type", required=False, type=str, default="classes",
+                        help="Define whether to return ontology classes, properties, or both")
 
     arguments = parser.parse_args()
     if not os.path.exists(arguments.source):
@@ -57,4 +59,4 @@ if __name__ == "__main__":
     map_file(arguments.source, target, output_file=arguments.output, csv_columns=csv_columns,
                          excl_deprecated=arguments.excl_deprecated, mapper=mapper, max_mappings=arguments.top_mappings,
                          min_score=arguments.min_score, base_iris=iris, save_graphs=arguments.save_term_graphs,
-                         save_mappings=True, separator=arguments.separator, use_cache=cache_exists(target))
+                         save_mappings=True, separator=arguments.separator, use_cache=cache_exists(target), term_type=arguments.term_type)
