@@ -1,4 +1,3 @@
-"""Provides Text2Term class"""
 import os
 import sys
 import json
@@ -7,9 +6,9 @@ import time
 import datetime
 import owlready2
 import pandas as pd
-from shutil import rmtree
 from text2term import onto_utils
 from text2term.mapper import Mapper
+from text2term import onto_cache
 from text2term.term_collector import OntologyTermCollector
 from text2term.term_graph_generator import TermGraphGenerator
 from text2term.bioportal_mapper import BioPortalAnnotatorMapper
@@ -59,11 +58,12 @@ df
 """
 def map_file(input_file, target_ontology, base_iris=(), csv_columns=(), excl_deprecated=False, max_mappings=3,
              mapper=Mapper.TFIDF, min_score=0.3, output_file='', save_graphs=False, save_mappings=False,
-             separator=',', use_cache=False):
+             separator=',', use_cache=False, term_type='classes'):
     source_terms, source_terms_ids = _load_data(input_file, csv_columns, separator)
     return map_terms(source_terms, target_ontology, source_terms_ids=source_terms_ids, base_iris=base_iris,
                     excl_deprecated=excl_deprecated, max_mappings=max_mappings, mapper=mapper, min_score=min_score,
-                    output_file=output_file, save_graphs=save_graphs, save_mappings=save_mappings, use_cache=use_cache)
+                    output_file=output_file, save_graphs=save_graphs, save_mappings=save_mappings, 
+                    use_cache=use_cache, term_type=term_type)
 
 """
 All parameters are the same as below, but tagged_terms_dict is a dictionary where the 
@@ -72,7 +72,8 @@ All parameters are the same as below, but tagged_terms_dict is a dictionary wher
     The dataframe returned is the same but contains a tags column
 """
 def map_tagged_terms(tagged_terms_dict, target_ontology, base_iris=(), excl_deprecated=False, max_mappings=3, min_score=0.3,
-        mapper=Mapper.TFIDF, output_file='', save_graphs=False, save_mappings=False, source_terms_ids=(), use_cache=False):
+        mapper=Mapper.TFIDF, output_file='', save_graphs=False, save_mappings=False, source_terms_ids=(), use_cache=False,
+        term_type='classes'):
     # If the input is a dict, use keys. If it is a list, it is a list of TaggedTerms
     if isinstance(tagged_terms_dict, dict):
         terms = list(tagged_terms_dict.keys())
@@ -89,7 +90,8 @@ def map_tagged_terms(tagged_terms_dict, target_ontology, base_iris=(), excl_depr
     # Run the mapper
     df = map_terms(terms, target_ontology, base_iris=base_iris, excl_deprecated=excl_deprecated, \
                     max_mappings=max_mappings, min_score=min_score, mapper=mapper, output_file=output_file, \
-                    save_graphs=save_graphs, source_terms_ids=source_terms_ids, use_cache=use_cache)
+                    save_graphs=save_graphs, source_terms_ids=source_terms_ids, use_cache=use_cache, \
+                    term_type=term_type)
 
     # For each term in dict, add tags to corresponding mappings row in "Tags" Column
     if isinstance(tagged_terms_dict, dict):
@@ -105,7 +107,7 @@ def map_tagged_terms(tagged_terms_dict, target_ontology, base_iris=(), excl_depr
             df.loc[df['Source Term'] == term.get_term(), "Tags"] = to_store
 
     if save_mappings:
-        _save_mappings(df, output_file, min_score, mapper, target_ontology, base_iris, excl_deprecated, max_mappings)
+        _save_mappings(df, output_file, min_score, mapper, target_ontology, base_iris, excl_deprecated, max_mappings, term_type)
     return df
 
 """
@@ -145,7 +147,8 @@ df
     Data frame containing the generated ontology mappings
 """
 def map_terms(source_terms, target_ontology, base_iris=(), excl_deprecated=False, max_mappings=3, min_score=0.3,
-        mapper=Mapper.TFIDF, output_file='', save_graphs=False, save_mappings=False, source_terms_ids=(), use_cache=False):
+        mapper=Mapper.TFIDF, output_file='', save_graphs=False, save_mappings=False, source_terms_ids=(), 
+        use_cache=False, term_type='classes'):
     if len(source_terms_ids) != len(source_terms):
         if len(source_terms_ids) > 0:
             sys.stderr.write("Warning: Source Term Ids are non-zero, but will not be used.")
@@ -156,30 +159,19 @@ def map_terms(source_terms, target_ontology, base_iris=(), excl_deprecated=False
     if mapper in {Mapper.ZOOMA, Mapper.BIOPORTAL}:
         target_terms = '' if target_ontology.lower() == 'all' else target_ontology
     else:
-        target_terms = _load_ontology(target_ontology, base_iris, excl_deprecated, use_cache)
+        target_terms = _load_ontology(target_ontology, base_iris, excl_deprecated, use_cache, term_type)
     mappings_df = _do_mapping(source_terms, source_terms_ids, target_terms, mapper, max_mappings, min_score)
     if save_mappings:
-        _save_mappings(mappings_df, output_file, min_score, mapper, target_ontology, base_iris, excl_deprecated, max_mappings)
+        _save_mappings(mappings_df, output_file, min_score, mapper, target_ontology, base_iris, excl_deprecated, max_mappings, term_type)
     if save_graphs:
         _save_graphs(target_terms, output_file)
     return mappings_df
 
-"""
-CACHING FUNCTIONS -- Public
-"""
-# Caches many ontologies from a csv
-def cache_ontology_set(ontology_registry_path):
-    registry = pd.read_csv(ontology_registry_path)
-    for index, row in registry.iterrows():
-        try:
-            cache_ontology(row.url, row.acronym)
-        except Exception as err:
-            sys.stderr.write("Could not cache ontology", row.acronym, "due to error:", err)
-        owlready2.default_world.ontologies.clear()
-
 # Caches a single ontology
-def cache_ontology(ontology_url, ontology_acronym, base_iris=()):
-    ontology_terms = _load_ontology(ontology_url, base_iris, exclude_deprecated=False)
+def cache_ontology(ontology_url, ontology_acronym="", base_iris=()):
+    if ontology_acronym == "":
+        ontology_acronym = ontology_url
+    ontology_terms = _load_ontology(ontology_url, base_iris, exclude_deprecated=False, term_type='both')
     cache_dir = "cache/" + ontology_acronym + "/"
     if not os.path.exists(cache_dir):
         os.makedirs(cache_dir)
@@ -187,23 +179,7 @@ def cache_ontology(ontology_url, ontology_acronym, base_iris=()):
     _serialize_ontology(ontology_terms, ontology_acronym, cache_dir)
     _save_graphs(ontology_terms, output_file=cache_dir + ontology_acronym)
     ontology_terms.clear()
-
-# Will check if an acronym exists in the cache
-def cache_exists(ontology_acronym):
-    return os.path.exists("cache/" + ontology_acronym)
-
-# Clears the cache
-def clear_cache(ontology_acronym=''):
-    cache_dir = "cache/" 
-    if ontology_acronym != '':
-        cache_dir = os.path.join(cache_dir, ontology_acronym)
-    # Is equivalent to: rm -r cache_dir
-    try:
-        rmtree(cache_dir)
-        sys.stderr.write("Cache has been cleared successfully")
-    except OSError as error:
-        sys.stderr.write("Cache cannot be removed:")
-        sys.stderr.write(error)
+    return onto_cache.OntologyCache(ontology_acronym)
 
 """
 PRIVATE/HELPER FUNCTIONS
@@ -227,14 +203,15 @@ def _load_data(input_file_path, csv_column_names, separator):
         term_ids = onto_utils.generate_iris(len(terms))
     return terms, term_ids
 
-def _load_ontology(ontology, iris, exclude_deprecated, use_cache=False):
+def _load_ontology(ontology, iris, exclude_deprecated, use_cache=False, term_type='classes'):
     term_collector = OntologyTermCollector()
     if use_cache:
         pickle_file = "cache/" + ontology + "/" + ontology + "-term-details.pickle"
         onto_terms_unfiltered = pickle.load(open(pickle_file, "rb"))
-        onto_terms = term_collector.filter_terms(onto_terms_unfiltered, iris, exclude_deprecated)
+        onto_terms = term_collector.filter_terms(onto_terms_unfiltered, iris, exclude_deprecated, term_type)
     else:
-        onto_terms = term_collector.get_ontology_terms(ontology, base_iris=iris, exclude_deprecated=exclude_deprecated)
+
+        onto_terms = term_collector.get_ontology_terms(ontology, base_iris=iris, exclude_deprecated=exclude_deprecated, term_type=term_type)
     if len(onto_terms) == 0:
         raise RuntimeError("Could not find any terms in the given ontology.")
     return onto_terms
@@ -255,7 +232,7 @@ def _do_mapping(source_terms, source_term_ids, ontology_terms, mapper, max_mappi
     else:
         raise ValueError("Unsupported mapper: " + mapper)
 
-def _save_mappings(mappings, output_file, min_score, mapper, target_ontology, base_iris, excl_deprecated, max_mappings):
+def _save_mappings(mappings, output_file, min_score, mapper, target_ontology, base_iris, excl_deprecated, max_mappings, term_type):
     if os.path.dirname(output_file):  # create output directories if needed
         os.makedirs(os.path.dirname(output_file), exist_ok=True)
     with open(output_file, "a") as f:
@@ -266,7 +243,8 @@ def _save_mappings(mappings, output_file, min_score, mapper, target_ontology, ba
         f.write("# Mapper: %s\n" % mapper.value)
         f.write("# Base IRIs: %s\n" % (base_iris,))
         f.write("# Max Mappings: %d\n" % max_mappings)
-        f.write("# Depricated Terms ")
+        f.write("# Term Type: %s\n" % term_type)
+        f.write("# Deprecated Terms ")
         f.write("Excluded\n" if excl_deprecated else "Included\n")
     mappings.to_csv(output_file, index=False, mode='a')
 
